HighlightsPlugin class

Implemented types

Constructors

HighlightsPlugin({bool debug = false})

Properties

debug bool
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

getHighlights(String code, String? language, String? theme, List<PhraseLocation>? emphasisLocations) Future<List<CodeHighlight>>
override
getLanguages() Future<List<String>>
override
getThemes() Future<List<String>>
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setDarkMode(bool useDarkMode) Future<void>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited